@@ -13,16 +13,22 @@ class BaseConnection(object):
     Child classes should implement at least
     connect() and disconnect() methods.
     """
+
+    retryable_exceptions = ()
+
     def __init__(self, num, **options):
         self._connection = None
         self.num = num
 
+    def __repr__(self):
+        return '<%s: num=%s>' % (self.__class__.__name__, self.num)
+
     @property
     def connection(self):
         if self._connection is None:
             self._connection = self.connect()
         return self._connection
-    
+
     def close(self):
         if self._connection:
             self.disconnect()
